package com.taauav.front.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.admin.entity.SysCity;
import com.taauav.admin.entity.TauvWaterWarn;
import com.taauav.admin.service.ISysCityService;
import com.taauav.admin.service.ITauvDriverService;
import com.taauav.admin.service.ITauvWaterTrendService;
import com.taauav.common.bean.Response;
import com.taauav.common.util.FunctionUtils;
import com.taauav.front.service.IUserWaterWarnService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * 指挥大屏-水质管理 控制器
 *
 * @author daixiantong
 * @date 2020-05-22
 */
@RestController
@RequestMapping("/index/water")
public class IndexWaterController {
    @Autowired
    private IUserWaterWarnService waterWarnService;
    @Resource
    private Response response;
    @Autowired
    private ITauvWaterTrendService waterTrendService;
    @Autowired
    private ISysCityService cityService;
    @Autowired
    private ITauvDriverService driverService;

    /**
     * 水质管理右侧 - 水质预警列表
     * @return
     */
    @GetMapping("/warn")
    public Response getWarnList() {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        wrapper.eq("status", 2);
        wrapper.orderByDesc("warn_time");
        wrapper.last("limit 5");
        List<TauvWaterWarn> list = waterWarnService.list(wrapper);
        if (list != null && list.size() > 0) {
            for (TauvWaterWarn item : list) {
                item.setStatusText(FunctionUtils.getArrayText(item.getStatus().toString(), item.statusList()));
                item.setWarnLevelText(FunctionUtils.getArrayText(item.getWarnLevel().toString(), item.levelList()));
                item.setWarnTypeText(FunctionUtils.getArrayText(item.getWarnType().toString(), item.typeList()));
                SysCity city = cityService.getInfoById(item.getDriverArea());
                item.setAreaName(city != null ? city.getName() : "");
            }
        }
        return response.success(list);
    }

    /**
     * 水质管理右侧 - 水质趋势模拟预测
     * @return
     */
    @GetMapping("/trend")
    public Response getTrendList() {
        return waterTrendService.getIndexTrendList();
    }

    /**
     * 获取所有区级河湖坐标点
     * @return
     */
    @GetMapping("/driver")
    public Response getAllDriverPoints() {
        return driverService.getAllDriverList();
    }
}
