package com.taauav.front.controller;


import com.taauav.common.bean.Menu;
import com.taauav.common.bean.Response;
import com.taauav.front.entity.UserAuthRule;
import com.taauav.front.service.IUserAuthRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;


import javax.validation.Valid;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author 鲲鹏
 * @since 2020-05-16
 */
@RestController
@RequestMapping("/front/authrule")
public class UserAuthRuleController extends FrontBaseController {

    @Autowired
    private IUserAuthRuleService userAuthRuleService;
    @Autowired
    private Response response;

    private static final String controllerName = "userauthrule";

    /**
     * 后台菜单-列表页面
     *
     * @return
     */
    @GetMapping("/index")
//    @RequiresPermissions(controllerName + ":" + PermissionConstants.LIST_PERMISSION)
    public Response index(@RequestBody(required = false) Map<String, String> request) {
        return userAuthRuleService.getRulePageList(request);
    }

    /**
     * 后台菜单-编辑页面
     *
     * @return
     */
    @RequestMapping("/edit")
//    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response edit(@RequestBody @Valid UserAuthRule authRule, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            String msg = bindingResult.getFieldError().getDefaultMessage();
            return response.failure(msg);
        }
        return userAuthRuleService.editRule(authRule);
    }

    /**
     * 后台菜单-获取编辑数据
     *
     * @param id
     * @return
     */
    @GetMapping("/getAuthInfo")
//    @RequiresPermissions(controllerName + ":" + PermissionConstants.EDIT_PERMISSION)
    public Response getAuthInfo(Integer id) {
        Map<String, Object> map = new HashMap<>(12);
        UserAuthRule info = userAuthRuleService.getInfoById(id);
        List<Menu> menuList = userAuthRuleService.buildTreeMenu();
        map.put("title", info.getTitle());
        map.put("name", info.getName());
        map.put("icon", info.getIcon());
        map.put("remark", info.getRemark());
        map.put("sort", info.getSort());
        map.put("hasChild", info.getHasChild());
        map.put("type", info.getType());
        map.put("status", info.getStatus());
        map.put("permission", info.getPermission());
        map.put("id", info.getId());
        map.put("pid", info.getPid());
        map.put("menuList", menuList);
        return response.success(map);
    }

    /**
     * 后台菜单-添加页面
     *
     * @return
     */
    @PostMapping("/add")
//    @RequiresPermissions(controllerName + ":" + PermissionConstants.ADD_PERMISSION)
    public Response add(@RequestBody @Valid UserAuthRule authRule, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            String msg = bindingResult.getFieldError().getDefaultMessage();
            return response.failure(msg);
        }
        return userAuthRuleService.addRule(authRule);
    }

    /**
     * 后台菜单-删除页面
     *
     * @return
     */
    @PostMapping("/del")
//    @RequiresPermissions(controllerName + ":" + PermissionConstants.REMOVE_PERMISSION)
    public Response del(@RequestBody UserAuthRule authRule) {
        return userAuthRuleService.delRule(authRule);
    }

    /**
     * 后台菜单设置状态
     *
     * @param map
     * @return
     */
    @PostMapping("/editStatus")
//    @RequiresPermissions(controllerName + ":" + PermissionConstants.STATUS_PERMISSION)
    public Response editStatus(@RequestBody Map<String, String> map) {
        return userAuthRuleService.editStatus(map);
    }

}
