package com.taauav.front.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.admin.entity.TauvInspectQuestion;
import com.taauav.common.bean.Response;
import com.taauav.front.mapper.UserInspectQuestionMapper;
import com.taauav.front.mapper.UserWaterAlarmInfoMapper;
import com.taauav.front.mapper.UserWaterAlarmMapper;
import com.taauav.front.vo.inspectquestion.InspectQuestionCategoryVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.*;
import java.util.*;

@RestController
@RequestMapping("/front/data")
public class UserDataStatisticsController {

    @Autowired
    private UserInspectQuestionMapper inspectQuestionMapper;
    @Autowired
    private UserWaterAlarmInfoMapper userWaterAlarmInfoMapper;
    @Autowired
    private UserWaterAlarmMapper userWaterAlarmMapper;
    @Autowired
    private Response response;

    @GetMapping("/index")
    public Response index() {
        // 巡检问题处理情况统计
        Map<String, Object> inspectQuestionInfo = getInspectQuestionInfo();
        // 获取月度巡检问题统计
        List<Map<String, Integer>> monthQuestionList = getMonthQuestionList();
        // 巡检问题类型统计
        List<InspectQuestionCategoryVo> inspectQuestionCategoryList = inspectQuestionMapper.getInspectQuestionCategoryList();
        // 获取水质警告分类统计列表
        List<Map<String, Object>> waterAlarmCategoryList = userWaterAlarmInfoMapper.getWaterAlarmCategoryList();

        // 返回结果
        Map<String, Object> result = new HashMap<>();
        result.put("inspectQuestionInfo", inspectQuestionInfo);
        result.put("monthQuestionList", monthQuestionList);
        result.put("inspectQuestionCategoryList", inspectQuestionCategoryList);
        result.put("waterAlarmCategoryList", waterAlarmCategoryList);
        return response.success(result);
    }

    /**
     * 巡检问题处理情况统计
     *
     * @return
     */
    private Map<String, Object> getInspectQuestionInfo() {
        Map<String, Object> result = new HashMap<>();
        // 获取已发现问题数
        Integer totalNum = inspectQuestionMapper.selectCount(new LambdaQueryWrapper<TauvInspectQuestion>()
                .eq(TauvInspectQuestion::getMark, 1));
        result.put("totalNum", totalNum);
        // 获取已解决问题数
        Integer finishedNum = inspectQuestionMapper.selectCount(new LambdaQueryWrapper<TauvInspectQuestion>()
                .eq(TauvInspectQuestion::getStatus, 3)
                .eq(TauvInspectQuestion::getMark, 1));
        result.put("finishedNum", finishedNum);
        // 已处理占比
        if (totalNum > 0) {
            result.put("percentage", String.format("%.2f", (float) finishedNum / (float) totalNum * 100));
        } else {
            result.put("percentage", "0.00");
        }
        return result;
    }

    /**
     * 月度巡检问题统计
     *
     * @return
     */
    private List<Map<String, Integer>> getMonthQuestionList() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Calendar date = Calendar.getInstance();
        Integer year = Integer.valueOf(date.get(Calendar.YEAR));
        List<Map<String, Integer>> mapList = new ArrayList<>();
        for (int i = 1; i <= 12; i++) {
            Date beginTime = getBeginTime(year, i);
            System.out.println(sdf.format(beginTime));

            Date endTime = getEndTime(year, i);
            System.out.println(sdf.format(endTime));

            // 已完成数量
            QueryWrapper<TauvInspectQuestion> queryWrapper = new QueryWrapper<>();
            queryWrapper.between("create_time", sdf.format(beginTime), sdf.format(endTime));
            queryWrapper.eq("status", 3);
            queryWrapper.eq("mark", 1);
            Integer finishedNum = inspectQuestionMapper.selectCount(queryWrapper);

            QueryWrapper<TauvInspectQuestion> queryWrapper2 = new QueryWrapper<>();
            queryWrapper2.between("create_time", sdf.format(beginTime), sdf.format(endTime));
            queryWrapper2.le("status", 2);
            queryWrapper2.eq("mark", 1);
            Integer waitNum = inspectQuestionMapper.selectCount(queryWrapper2);

            Map<String, Integer> map = new HashMap<>();
            map.put("month", i);
            map.put("finishedNum", finishedNum);
            map.put("waitNum", waitNum);
            map.put("totalNum", finishedNum + waitNum);
            mapList.add(map);
        }
        return mapList;
    }

    public static Date getBeginTime(int year, int month) {
        YearMonth yearMonth = YearMonth.of(year, month);
        LocalDate localDate = yearMonth.atDay(1);
        LocalDateTime startOfDay = localDate.atStartOfDay();
        ZonedDateTime zonedDateTime = startOfDay.atZone(ZoneId.of("Asia/Shanghai"));

        return Date.from(zonedDateTime.toInstant());
    }

    public static Date getEndTime(int year, int month) {
        YearMonth yearMonth = YearMonth.of(year, month);
        LocalDate endOfMonth = yearMonth.atEndOfMonth();
        LocalDateTime localDateTime = endOfMonth.atTime(23, 59, 59, 999);
        ZonedDateTime zonedDateTime = localDateTime.atZone(ZoneId.of("Asia/Shanghai"));
        return Date.from(zonedDateTime.toInstant());
    }

    /**
     * 巡检问题河湖统计
     *
     * @return
     */
    @GetMapping("/getInspectQuestionDriverList")
    private Response getInspectQuestionDriverList(Integer type) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Calendar date = Calendar.getInstance();
        if (type == 2) {
            // 前三个月
            String endTime = sdf.format(new Date());
            String startTime = addMonthDate(endTime, -3, "yyyy-MM-dd HH:mm:ss");
            List<Map<String, Object>> mapList = inspectQuestionMapper.getInspectQuestionDriverList(startTime, endTime);
            return response.success(mapList);
        } else if (type == 3) {
            // 前半年
            String endTime = sdf.format(new Date());
            String startTime = addMonthDate(endTime, -6, "yyyy-MM-dd HH:mm:ss");
            List<Map<String, Object>> mapList = inspectQuestionMapper.getInspectQuestionDriverList(startTime, endTime);
            return response.success(mapList);
        } else {
            // 当月
            Integer year = Integer.valueOf(date.get(Calendar.YEAR));
            Integer month = Integer.valueOf(date.get(Calendar.MONTH)) + 1;

            Date beginTime = getBeginTime(year, month);
            System.out.println(sdf.format(beginTime));

            Date endTime = getEndTime(year, month);
            System.out.println(sdf.format(endTime));

            List<Map<String, Object>> mapList = inspectQuestionMapper.getInspectQuestionDriverList(sdf.format(beginTime), sdf.format(endTime));
            return response.success(mapList);
        }
    }

    /**
     * 得到几个月之后的时间
     *
     * @param date
     * @param month
     * @return
     */
    public static String addMonthDate(String date, int month, String pattern) {
        String nowDate = null;
        SimpleDateFormat format = new SimpleDateFormat(pattern);
        try {
            Date parse = format.parse(date);
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(parse);
            calendar.add(Calendar.MONTH, month);
            nowDate = format.format(calendar.getTime());
        } catch (ParseException e) {
        }
        return nowDate;
    }

    /**
     * 获取水质污染程度统计
     *
     * @param type 类型：1当月 2三个月 3半年
     * @return
     */
    @GetMapping("/getWaterAlarmInfoList")
    private Response getWaterAlarmInfoList(Integer type) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Calendar date = Calendar.getInstance();
        if (type == 2) {
            // 前三个月
            String endTime = sdf.format(new Date());
            String startTime = addMonthDate(endTime, -3, "yyyy-MM-dd HH:mm:ss");
            List<Map<String, Object>> mapList = userWaterAlarmMapper.getWaterAlarmInfoList(startTime, endTime);
            return response.success(mapList);
        } else if (type == 3) {
            // 前半年
            String endTime = sdf.format(new Date());
            String startTime = addMonthDate(endTime, -6, "yyyy-MM-dd HH:mm:ss");
            List<Map<String, Object>> mapList = userWaterAlarmMapper.getWaterAlarmInfoList(startTime, endTime);
            return response.success(mapList);
        } else {
            // 当月
            Integer year = Integer.valueOf(date.get(Calendar.YEAR));
            Integer month = Integer.valueOf(date.get(Calendar.MONTH)) + 1;
            Date beginTime = getBeginTime(year, month);
            Date endTime = getEndTime(year, month);
            List<Map<String, Object>> mapList = userWaterAlarmMapper.getWaterAlarmInfoList(sdf.format(beginTime), sdf.format(endTime));
            return response.success(mapList);
        }
    }
}
