package com.taauav.front.mapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.taauav.admin.entity.TauvInspectQuestion;
import com.taauav.front.dto.IndexQuestionDto;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.taauav.front.query.UserInspectQuestionQuery;
import com.taauav.front.vo.IndexQuestionDetailVo;
import com.taauav.front.vo.IndexQuestionListVo;
import com.taauav.front.vo.inspectquestion.InspectQuestionCategoryVo;
import com.taauav.front.vo.inspectquestion.UserInspectQuestionInfoVo;
import com.taauav.front.vo.inspectquestion.UserInspectQuestionListVo;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 问题管理 Mapper 接口
 * </p>
 *
 * @author 鲲鹏
 * @since 2020-05-14
 */
public interface UserInspectQuestionMapper extends BaseMapper<TauvInspectQuestion> {

    /**
     * 获取巡检问题列表
     *
     * @param query 查询条件
     * @return
     */
    List<UserInspectQuestionListVo> getInspectQuestionList(IPage<UserInspectQuestionListVo> page, @RequestParam("query") UserInspectQuestionQuery query);

    /**
     * 根据ID获取问题详情
     *
     * @param id 问题ID
     * @return
     */
    UserInspectQuestionInfoVo getInspectQuestionInfoById(Integer id);

    /**
     * 获取巡检问题分类统计列表
     *
     * @return
     */
    List<InspectQuestionCategoryVo> getInspectQuestionCategoryList();

    /**
     * 大屏待处理污染问题统计
     *
     * @param category 分类ID
     * @return
     */
    Map<String, Object> getCategoryQuestionInfo(Integer category);

    /**
     * 大屏巡检问题河湖统计
     *
     * @return
     */
    List<Map<String, Object>> getQuestionDriverList();

    /**
     * 大屏区属问题河湖统计
     *
     * @return
     */
    List<Map<String, Object>> getQuestionDriverAreaList();

    /**
     * 数据类型巡检问题河湖统计
     *
     * @return
     */
    List<Map<String, Object>> getInspectQuestionDriverList(@Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 指挥大屏问题清单 - 问题列表分页数据
     *
     * @param indexQuestionDto
     * @return
     */
    List<IndexQuestionListVo> selectIndexPageList(@Param("param") IndexQuestionDto indexQuestionDto);

    /**
     * 指挥大屏-问题详情
     *
     * @param id
     * @return
     */
    IndexQuestionDetailVo getQuestionDetail(Integer id);
}
